@@ -423,9 +423,7 @@ ee_create_credentials_gcs <- function(email) {
       sprintf("Unable to find a service account key (SAK) file in: %s",  bold(ee_path_user)),
       "Please, download and save the key manually on the path mentioned",
       "before. A compressible tutorial to obtain their SAK file is available in:",
-      "> https://github.com/r-spatial/rgee/tree/help/gcs/",
-      "> https://cloud.google.com/iam/docs/creating-managing-service-account-keys/",
-      "> https://console.cloud.google.com/apis/credentials/serviceaccountkey/",
+      "> https://r-spatial.github.io/rgee/articles/rgee05.html",
       bold("Until you do not save a SKA file, the following functions will not work:"),
       "- rgee::ee_gcs_to_local()",
       "- ee_extract(..., via = \"gcs\")",
